pub(crate) fn can_continue<'a, FEN: FoundryEvmNetwork>(
invariant_contract: &InvariantContract<'a>,
invariant_test: &mut InvariantTest,
invariant_run: &mut InvariantTestRun<FEN>,
invariant_config: &InvariantConfig,
call_result: RawCallResult<FEN>,
state_changeset: &StateChangeset,
handler_target: Address,
handler_selector: Selector,
pre_merge_edges_hash: Option<B256>,
) -> Result<ContinueOutcome<'a>>Expand description
Returns if invariant test can continue and last successful call result of the invariant test function (if it can continue).
For optimization mode (int256 return), tracks the max value but never fails on invariant. For check mode, asserts the invariant and fails if broken.
handler_target / handler_selector identify the just-executed call, used to
attribute handler-side assertion failures.