pub(crate) fn is_assertion_failure<FEN: FoundryEvmNetwork>(
call_result: &RawCallResult<FEN>,
) -> boolExpand description
Returns true if this call failed due to a Solidity assertion:
Panic(0x01), or- legacy invalid opcode assert behavior.
pub(crate) fn is_assertion_failure<FEN: FoundryEvmNetwork>(
call_result: &RawCallResult<FEN>,
) -> boolReturns true if this call failed due to a Solidity assertion:
Panic(0x01), or